@@ -15,9 +15,9 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
  *************************************************************************/
 
-#if !defined(OPERATION__H)
+#if !defined(KPMCORE_OPERATION_H)
 
-#define OPERATION__H
+#define KPMCORE_OPERATION_H
 
 #include "util/libpartitionmanagerexport.h"
 
@@ -112,7 +112,7 @@ public:
         return m_Status;    /**< @return the current status */
     }
     virtual QString statusText() const;
-    virtual QIcon statusIcon() const;
+    virtual QString statusIcon() const;
 
     virtual void setStatus(OperationStatus s) {
         m_Status = s;    /**< @param s the new status */
